"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @file For plugin to collect test classification data
 */
const pipcook_core_1 = require("@pipcook/pipcook-core");
const path = __importStar(require("path"));
const assert = __importStar(require("assert"));
const fs = __importStar(require("fs-extra"));
const uuid_1 = require("uuid");
const glob_promise_1 = __importDefault(require("glob-promise"));
const sync_1 = __importDefault(require("csv-parse/lib/sync"));
const sync_2 = __importDefault(require("csv-stringify/lib/sync"));
const writeCsvFile = (url) => {
    const records = sync_1.default(fs.readFileSync(url), {
        columns: true,
        skip_empty_lines: true,
        skip_lines_with_error: true
    });
    return records;
};
/**
 * collect csv data
 */
const textClassDataCollect = (args) => __awaiter(void 0, void 0, void 0, function* () {
    let { url = '', dataDir } = args;
    yield fs.remove(dataDir);
    yield fs.ensureDir(dataDir);
    assert.ok(url, 'Please specify a url of zip of your data');
    const fileName = url.split(path.sep)[url.split(path.sep).length - 1];
    const extension = fileName.split('.');
    assert.ok(extension[extension.length - 1] === 'zip', 'The dataset provided should be a zip file');
    let isDownload = false;
    if (/^file:\/\/.*/.test(url)) {
        url = url.substring(7);
    }
    else {
        const targetPath = path.join(dataDir, uuid_1.v1() + '.zip');
        console.log('downloading dataset ...');
        yield pipcook_core_1.download(url, targetPath);
        url = targetPath;
        isDownload = true;
    }
    const tempDir = path.join(dataDir, 'temp');
    console.log('unzip and collecting data...');
    yield pipcook_core_1.unZipData(url, tempDir);
    const csvPaths = yield glob_promise_1.default(path.join(tempDir, '+(train|validation|test)', '*.csv'));
    const trainData = [];
    const validationData = [];
    const testData = [];
    for (let i = 0; i < csvPaths.length; i++) {
        const csvPath = csvPaths[i];
        const splitString = csvPath.split(path.sep);
        const trainType = splitString[splitString.length - 2];
        const result = yield writeCsvFile(csvPath);
        if (trainType === 'train') {
            trainData.push(...result);
        }
        if (trainType === 'validation') {
            validationData.push(...result);
        }
        if (trainType === 'test') {
            testData.push(...result);
        }
    }
    if (trainData.length > 0) {
        fs.outputFileSync(path.join(dataDir, 'train.csv'), sync_2.default(trainData, { header: true }));
    }
    if (validationData.length > 0) {
        fs.outputFileSync(path.join(dataDir, 'validation.csv'), sync_2.default(validationData, { header: true }));
    }
    if (testData.length > 0) {
        fs.outputFileSync(path.join(dataDir, 'test.csv'), sync_2.default(testData, { header: true }));
    }
    fs.removeSync(tempDir);
    if (isDownload) {
        fs.removeSync(url);
    }
});
exports.default = textClassDataCollect;
//# sourceMappingURL=index.js.map